@@ -6,9 +6,8 @@ from credsweeper.utils import Util
 
 
 class Config:
-    """
-    Class that contain configs that can be changed by user
-    """
+    """Class that contain configs that can be changed by user."""
+
     NOT_ALLOWED_PATH = [
         ".*\\.min\\.js", ".*message.*\\.properties", ".*locale.*\\.properties", ".*makefile.*", ".*package-lock\\.json",
         ".*package\\.json", ".*\\.css", ".*\\.scss"
@@ -28,3 +27,5 @@ class Config:
         self.ml_validation: bool = config["validation"]["ml_validation"]
         self.api_validation: bool = config["validation"]["api_validation"]
         self.use_filters: bool = config["use_filters"]
+        self.line_data_output: bool = config["line_data_output"]
+        self.candidate_output: bool = config["candidate_output"]
