@@ -5,12 +5,10 @@ from credsweeper.file_handler.analysis_target import AnalysisTarget
 
 
 class ContentProvider(ABC):
-    """Base class to provide access to analysis targets for scanned object"""
+    """Base class to provide access to analysis targets for scanned object."""
+
     @abstractmethod
-    def __init__(self,
-                 file_path: str,
-                 change_type: Optional[str] = None,
-                 diff: Optional[List[Dict]] = None) -> None:
+    def __init__(self, file_path: str, change_type: Optional[str] = None, diff: Optional[List[Dict]] = None) -> None:
         raise NotImplementedError()
 
     def get_file_path(self) -> str:
@@ -18,8 +16,10 @@ class ContentProvider(ABC):
 
     @abstractmethod
     def get_analysis_target(self) -> List[AnalysisTarget]:
-        """Load and preprocess file diff data to scan
+        """Load and preprocess file diff data to scan.
 
         Return:
-            list of AnalysisTarget, row objects to analyse"""
+            row objects to analysing
+
+        """
         raise NotImplementedError()
